@@ -2,8 +2,8 @@ from typing import Any, Dict, List, Optional, Union
 
 import pandas as pd
 
-from .algs import Reranking
 from .metrics import *
+from .reranker import Reranker
 
 
 def rerank(
@@ -14,5 +14,5 @@ def rerank(
     algorithm: str = "det_greedy",
     verbose: bool = False,
 ) -> Union[List[int], pd.DataFrame]:
-    rerank = Reranking(item_attribute, desired_distribution, max_na)
+    rerank = Reranker(item_attribute, desired_distribution, max_na)
     return rerank(k_max, algorithm, verbose)
